@@ -19,11 +19,7 @@ fvt_begin_testcase($tcname);
 $dbh = DBI->connect("dbi:DB2:$DATABASE", "$USERID", "$PASSWORD", {PrintError => 0});
 check_error("CONNECT");
 
-$sth = $dbh->prepare( 'DROP PROCEDURE SP_Example' );
-check_error( 'PREPARE' );
-
-$sth->execute();
-check_error("EXECUTE DROP procedure");
+$dbh->do( 'DROP PROCEDURE SP_Example' );
 
 $statement = "CREATE PROCEDURE SP_Example () LANGUAGE SQL BEGIN RETURN 5; END";
 $sth = $dbh->prepare( $statement );
